# QStyler CHANGELOG

## Version 0.1.4

-   Improved toolbar widget
-   Added new icons for toolbar actions
-   Improved and added to Unit testing framework
-   Updated and expanded CI integration
-   Fixed issue with menubar actions
-   Improved coverage data and quality
-   Bug Fixes
-   Added 2 new themes

* * *

## Version 0.1.3

-   Added toolbar to styler menu
-   Improved and added unittests
-   Better CI integration
-   Better coverage and autoformatting

* * *

## Version 0.1.2

-   Cleanup
-   Bug fixes
-   Added docstrings
-   Changed README gif

* * *

## Version 0.1.1

-   Imporoved UI
-   Improved README
-   Bug Fixes
-   Improved UnitTests
-   Improved CI workflow
-   Improved package workflow
-   Added executable creation workflow

* * *

## Version 0.1.0

### Added

-   initial release
-   added testing suite
-   full gui
-   pre-prapared themes
